==> amarok-2.9.70_pre20190111.tar.xz: amarok-2.9.70_pre20190111/src/core-impl/collections/audiocd/support/AudioCdDeviceInfo.h <==
/****************************************************************************************
 * copyright (C) 2008 Alejandro Wainzinger <aikawarazuni@gmail.com>
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AUDIOCD_DEVICE_INFO_H
#define AUDIOCD_DEVICE_INFO_H

#include "MediaDeviceInfo.h"

class AudioCdDeviceInfo : public MediaDeviceInfo
{
    Q_OBJECT
    public:
        AudioCdDeviceInfo(const QString &device, const QString &udi );
        ~AudioCdDeviceInfo();

        QString device() const;

    private:
        QString m_device;
};

#endif

==> amarok-3.0.81.tar.xz: amarok-3.0.81/src/core-impl/collections/audiocd/support/AudioCdDeviceInfo.h <==
/****************************************************************************************
 * copyright (C) 2008 Alejandro Wainzinger <aikawarazuni@gmail.com>
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AUDIOCD_DEVICE_INFO_H
#define AUDIOCD_DEVICE_INFO_H

#include "MediaDeviceInfo.h"

class AudioCdDeviceInfo : public MediaDeviceInfo
{
    Q_OBJECT
    public:
        AudioCdDeviceInfo(const QString &device, const QString &udi );
        ~AudioCdDeviceInfo() override;

        QString device() const;

    private:
        QString m_device;
};

#endif
